#
# spec file for package php5-pear-Mail_Mime
#
# Copyright (c) 2015 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           php5-pear-Mail_Mime
%define pear_name  Mail_Mime
%define pear_sname mail_mime
Summary:        Mail_Mime provides classes to create mime messages
License:        BSD-3-Clause
Group:          Productivity/Networking/Web/Servers
Version:        1.10.0
Release:        4.1
BuildArch:      noarch
Url:            http://pear.php.net/package/%{pear_name}
Source:         %{pear_name}-%{version}.tgz

BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildRequires:  php >= 5.0
%if 0%{?sles_version} == 10
BuildRequires:  php-macros
%else
BuildRequires:  php-devel >= 5.0
%endif
BuildRequires:  php-pear >= 1.6.0
Requires:       php >= 5.0
Requires:       php-pear >= 1.6.0
Requires:       php-pear-Mail_mimeDecode

Provides:       pear-%{pear_name}
Provides:       php-pear-%{pear_name}
# Fix for renaming (package convention)
Provides:       pear-%{pear_sname} = %{version}
Provides:       php-pear-%{pear_sname} = %{version}
Provides:       php5-pear-%{pear_sname} = %{version}
Obsoletes:      pear-%{pear_sname} < %{version}
Obsoletes:      php-pear-%{pear_sname} < %{version}
Obsoletes:      php5-pear-%{pear_sname} < %{version}

%description
Mail_Mime provides classes to deal with the creation and manipulation of mime messages.
It allows people to create Email messages consisting of:
* Text Parts
* HTML Parts
* Inline HTML Images
* Attachments
* Attached messages

Starting with version 1.4.0, it also allows non US-ASCII chars in filenames,
 subjects, recipients, etc, etc.

%prep
%setup -c

%build

%install
%{__mv} package*.xml %{pear_name}-%{version}
cd %{pear_name}-%{version}
PHP_PEAR_PHP_BIN="$(which php) -d memory_limit=50m"
%{__pear} -v \
        -d doc_dir=/doc \
        -d bin_dir=%{_bindir} \
        -d data_dir=%{php_peardir}/data \
        install --offline --nodeps -R "%{buildroot}" package.xml

%{__install} -D -m 0644 package.xml %{buildroot}%{php_pearxmldir}/%{pear_name}.xml

%{__rm} -rf %{buildroot}/{doc,tmp}
%{__rm} -rf %{buildroot}%{php_peardir}/.{filemap,lock,registry,channels,depdb,depdblock}

###rpmlint
# wrong-script-interpreter
%{__sed} -i -e "s|%{_prefix}|@prefix@|" scripts/phail.php
# fix permission
%{__chmod} 0644 scripts/phail.php 

cd ..

%php_pear_gen_filelist

%post
# on `rpm -ivh` PARAM is 1
# on `rpm -Uvh` PARAM is 2
if [ "$1" = "1" ]; then
  %{__pear} install --nodeps --soft --force --register-only %{php_pearxmldir}/%{pear_name}.xml
fi
if [ "$1" = "2" ]; then
  %{__pear} upgrade --offline --register-only %{php_pearxmldir}/%{pear_name}.xml
fi

%postun
# on `rpm -e` PARAM is 0
if [ "$1" = "0" ]; then
  %{__pear} uninstall --nodeps --ignore-errors --register-only pear.php.net/%{pear_name}
fi

%clean
%{__rm} -rf %{buildroot}

%files -f %{name}.files
%defattr(-, root, root)
%doc %{pear_name}-%{version}/scripts

%changelog
* Tue Sep 15 2015 aj@ajaissle.de
- New upstream release 1.10.0
  * Add possibility to add externally created Mail_mimePart objects as attachments [alec]
  * Add possibility to set preamble text for multipart messages [alec]
- Changes 1.9.0
  * Bug #20921: Make Mail_mimePart::encodeHeaderValue() a static method [alec]
  * Bug #20931: Really remove unset headers [alec]
  * Request #18772: Added methods for creating text/calendar messages [alec]
* Thu Dec 11 2014 aj@ajaissle.de
- New upstream release 1.8.9
  * Fixed Bug #20273: Incorrect handling of HTAB in encodeHeader() [alec]
  * Fixed Bug #20226: Mail_mimePart::encodeHeader does not encode ISO-2022-JP string [alec]
  * Fixed Bug #20222: Broken Compatybility with PHP4 [alec]
* Fri Nov  8 2013 aj@ajaissle.de
- New upstream release 1.8.8
  * Fixed warning/notice on (static vs. non-static) PEAR::raiseError() usage [alec]
  * Fixed Bug #19761: PHP5 warnings about return by reference [alec]
  * Fixed Bug #19770: Make cid generator more unique on Windows [alec]
  * Fixed Bug #19987: E_STRICT warning when null is passed by reference [alec]
* Fri Feb  1 2013 aj@ajaissle.de
- New upstram version 1.8.7
- Changelog 1.8.7
  * Bug #5333: Fix more return by reference errors [alec]
  * Bug #19754: Fix compatibility with PHP4 [alec]
- Changelog 1.8.6
  * Bug #19473: PEAR::isError() compatibility problem with PHP 5.4 [alec]
  * Bug #19497: Attachment filename is cut on slash character [alec]
  * Bug #19665: Add Mail-Reply-To and Mail-Followup-To to structured recipient headers list [alec]
- Changelog 1.8.5
  * Added possibility to set additional parameters of message part header, e.g. attachment size [alec]
  * Added automatic setting of attachment size via Content-Disposition header size parameter [alec]
- Changelog 1.8.4
  * Request #19406: Allow to set individual attachment part headers
    [alec]
  * Fixed Bug #18982: Non-static method Mail
    mimePart::encodeHeader() should not be called statically [alec]
- Changelog 1.8.3
  * Request #19009: Remove error_reporting from tests [alec]
  * Fixed Bug #19094: Email addresses do not have to contain a
    space between the name and address part [alec]
  * Fixed Bug #19328: Wrong encoding of filenames with comma [alec]
- Changelog 1.8.2
  * #18426: Fixed backward compatibility for "dfilename" parameter
    [alec]
  * Removed xmail.dtd, xmail.xsl from the package [alec]
  * Fixed handling of email addresses with quoted local part [alec]
* Thu Jan 12 2012 coolo@suse.com
- change license to be in spdx.org format
* Thu Jan 20 2011 chris@computersalat.de
- change to php_pear_gen_filelist macro
* Wed Jan 19 2011 chris@computersalat.de
- pkg rename php5-pear-Mail_Mime
- merge with php-pear-mail_mime, php5-pear-mail_mime
- update to 1.8.1
  * #18083: Not possible to set separate charset for attachment content
    and headers [alec]
- 1.8.0
  Bugs Fixed:
  * Double-addition of e-mail domain to content ID in HTML images [alec]
  * #17311: Multi-octet characters are split across adjacent
    'encoded-word's [alec]
  * #17573: Place charset parameter in first line of Content-Type header
    (if possible) [alec]
  Implemented Features:
  * #17518: addTo() method [alec]
- added php-macros
- cleanup spec
* Sat May 30 2009 chris@computersalat.de
- fixed post script
* Thu May 21 2009 chris@computersalat.de
- new version 1.5.2
- beautify spec
  o new spec header
  o package rename due to package convention
  o removed php4 stuff, deps
  o added Provides and Obsoletes for old package names.
    This should not break deps
- added stuff to automatically create correct filelist
  o tested against Factory (1120)
  o opensuse >= 1100 complains about
    "directory not owned by package"
- some rpmlint stuff
* Tue Dec 23 2008 rbos@opensuse.org
- Changed the pear install command, use package.xml instead of the tarbal
* Sat Jun 17 2006 suse-tux@gmx.de
- made spec file portable for older/new suse-versions
- removed #usedforbuild, added %%%%clean-macro
- added rpmmacros (changed "mv" to "%%%%__mv" etc.)
- removed Packager-tag :)
* Sun Jun 11 2006 suse-tux@gmx.de
- built for 10.0 because it's missing there
- added Packager-tag
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Thu Jan 19 2006 mmarek@suse.de
- fix filelist, remove temporary files created by pear installer
- unify php5-pear-*.spec files
- increase php's memory_limit during installation (parsing
  xml needs more than default 8M sometimes)
* Mon Jan 16 2006 mmarek@suse.cz
- created package to satisfy horde dependencies
